monkey.mailman.interceptors

Event handler interceptors. This uses the Pedestal interceptor library under the hood. Most functions are really just wrappers around Pedestal functions.

Event handler interceptors.  This uses the Pedestal interceptor library
under the hood.  Most functions are really just wrappers around Pedestal
functions.
raw docstring

empty-contextclj

source

handler-interceptorclj

(handler-interceptor handler)

Interceptor that invokes the handler with the context. Updates the context with the handler return value so it matches the handler-result spec.

Interceptor that invokes the handler with the context.  Updates the context
with the handler return value so it matches the `handler-result` spec.
sourceraw docstring

interceptor-handlerclj

(interceptor-handler interceptors exec)

Creates an event handler fn that uses the given interceptors as the interceptor chain and passes them to the executor, along with the context, that has the event added.

Creates an event handler fn that uses the given interceptors as the interceptor
chain and passes them to the executor, along with the context, that has the event
added.
sourceraw docstring

make-contextclj

(make-context evt)

Creates an initial interceptor context for given event.

Creates an initial interceptor context for given event.
sourceraw docstring

sanitize-resultclj

(sanitize-result & {:keys [event?] :or {event? s/event?}})
source

set-eventclj

(set-event ctx evt)

Sets the event on the context

Sets the event on the context
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries