Event handler interceptors. This uses the Pedestal interceptor library under the hood. Most functions are really just wrappers around Pedestal functions.
Event handler interceptors. This uses the Pedestal interceptor library under the hood. Most functions are really just wrappers around Pedestal functions.
(handler-interceptor handler)Interceptor that invokes the handler with the context. Updates the context
with the handler return value so it matches the handler-result spec.
Interceptor that invokes the handler with the context. Updates the context with the handler return value so it matches the `handler-result` spec.
(interceptor-handler interceptors exec)Creates an event handler fn that uses the given interceptors as the interceptor chain and passes them to the executor, along with the context, that has the event added.
Creates an event handler fn that uses the given interceptors as the interceptor chain and passes them to the executor, along with the context, that has the event added.
(make-context evt)Creates an initial interceptor context for given event.
Creates an initial interceptor context for given event.
(set-event ctx evt)Sets the event on the context
Sets the event on the context
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |